import { jsx, jsxs } from 'react/jsx-runtime';
import exampleTheme from './themes/ExampleTheme.js';
import { LexicalComposer } from '@lexical/react/LexicalComposer';
import { RichTextPlugin } from '@lexical/react/LexicalRichTextPlugin';
import { ContentEditable } from '@lexical/react/LexicalContentEditable';
import { HistoryPlugin } from '@lexical/react/LexicalHistoryPlugin';
import { AutoFocusPlugin } from '@lexical/react/LexicalAutoFocusPlugin';
import LexicalErrorBoundary from '@lexical/react/LexicalErrorBoundary';
import ToolbarPlugin from './plugins/ToolbarPlugin.js';
import { L as LexicalRichText_1 } from '../node_modules/@lexical/rich-text/LexicalRichText.js';
import { L as LexicalTable_1 } from '../node_modules/@lexical/table/LexicalTable.js';
import { L as LexicalList_1 } from '../node_modules/@lexical/list/LexicalList.js';
import { L as LexicalCode_1 } from '../node_modules/@lexical/code/LexicalCode.js';
import { L as LexicalLink_1 } from '../node_modules/@lexical/link/LexicalLink.js';
import { LinkPlugin } from '@lexical/react/LexicalLinkPlugin';
import { ListPlugin } from '@lexical/react/LexicalListPlugin';
import { MarkdownShortcutPlugin } from '@lexical/react/LexicalMarkdownShortcutPlugin';
import { L as LexicalMarkdown_1 } from '../node_modules/@lexical/markdown/LexicalMarkdown.js';
import { OnChangePlugin } from '@lexical/react/LexicalOnChangePlugin';
import ListMaxIndentLevelPlugin from './plugins/ListMaxIndentLevelPlugin.js';
import CodeHighlightPlugin from './plugins/CodeHighlightPlugin.js';
import PlaygroundAutoLinkPlugin from './plugins/AutoLinkPlugin.js';
import { useCallback } from 'react';
import { L as LexicalHtml_1 } from '../node_modules/@lexical/html/LexicalHtml.js';
import { InitialWithHtmlPlugin } from './plugins/InitialWithHtmlPlugin.js';
import { VideoNode } from './nodes/video.js';
import { ImageNode } from './nodes/image.js';
import { HeaderPlugin } from './plugins/HeaderPlugin.js';
import { $getRoot } from 'lexical';
import { VideoPlugin } from './plugins/VideoPlugin.js';
import { ImagePlugin } from './plugins/ImagePlugin.js';
import { getEditorImages, editorUploadImageUrl } from '../network/index.js';

function DefaultPlaceholder() {
    return jsx("div", { className: "editor-placeholder", children: "Enter some text..." });
}
const editorConfig = {
    // The editor theme
    theme: exampleTheme,
    // Handling of errors during update
    onError(error) {
        throw error;
    },
    // Any custom nodes go here
    nodes: [
        LexicalRichText_1.HeadingNode,
        LexicalList_1.ListNode,
        LexicalList_1.ListItemNode,
        LexicalRichText_1.QuoteNode,
        LexicalCode_1.CodeNode,
        LexicalCode_1.CodeHighlightNode,
        LexicalTable_1.TableNode,
        LexicalTable_1.TableCellNode,
        LexicalTable_1.TableRowNode,
        LexicalLink_1.AutoLinkNode,
        LexicalLink_1.LinkNode,
        VideoNode,
        ImageNode
    ]
};
function Editor({ getImages = getEditorImages, titlePlaceHolder, initialHtml: initHtml, onChange, Placeholder = DefaultPlaceholder, uploadImageUrl = editorUploadImageUrl }) {
    const onEditorChange = useCallback((editorState, editor) => {
        editorState.read(() => {
            const htmlString = LexicalHtml_1.$generateHtmlFromNodes(editor);
            if (htmlString !== initHtml && htmlString !== '<p class="editor-paragraph"><br></p>') {
                const firstNode = $getRoot().getChildAtIndex(0);
                let header = '';
                if (firstNode && firstNode.__tag === 'h1') {
                    header = firstNode.getTextContent();
                }
                onChange({ html: htmlString, title: header });
            }
        });
    }, [initHtml]);
    return (jsx(LexicalComposer, { initialConfig: editorConfig, children: jsxs("div", { className: "editor-container shadow-xl", children: [jsx(HeaderPlugin, { placeholder: titlePlaceHolder }), jsx(ToolbarPlugin, { getImages: getImages, uploadImageUrl: uploadImageUrl }), jsxs("div", { className: "editor-inner", children: [jsx(RichTextPlugin, { contentEditable: jsx(ContentEditable, { className: "editor-input" }), placeholder: jsx(Placeholder, {}), ErrorBoundary: LexicalErrorBoundary }), jsx(OnChangePlugin, { onChange: onEditorChange }), jsx(InitialWithHtmlPlugin, { html: initHtml }), jsx(HistoryPlugin, {}), jsx(AutoFocusPlugin, {}), jsx(CodeHighlightPlugin, {}), jsx(ListPlugin, {}), jsx(LinkPlugin, {}), jsx(PlaygroundAutoLinkPlugin, {}), jsx(ListMaxIndentLevelPlugin, { maxDepth: 7 }), jsx(MarkdownShortcutPlugin, { transformers: LexicalMarkdown_1.TRANSFORMERS }), jsx(VideoPlugin, {}), jsx(ImagePlugin, {})] })] }) }));
}

export { Editor };
