import { __awaiter } from '../../node_modules/tslib/tslib.es6.js';
import { jsxs, jsx, Fragment } from 'react/jsx-runtime';
import { useState, useCallback, useEffect, useMemo } from 'react';
import { ImageViewer } from './img-viewer.js';
import { Pagination, Button } from '@cpchain-foundation/ui';

function ImageSelection({ onSelect, onCancel, getFiles, uploadUrl }) {
    const [images, setImages] = useState([]);
    const [selected, setSelected] = useState([]);
    const [uploadProgress, setUploadProgress] = useState(0);
    const [loading, setLoading] = useState(false);
    const [count, setCount] = useState(0);
    const [offset, setOffset] = useState(0);
    const limit = 10;
    const loadImg = useCallback(() => __awaiter(this, void 0, void 0, function* () {
        if (getFiles) {
            setLoading(true);
            const { results: urls, count } = yield getFiles({ limit, offset });
            setImages(urls);
            setCount(count);
            setLoading(false);
        }
    }), [offset, limit]);
    useEffect(() => {
        loadImg();
    }, [limit, offset, getFiles]);
    const upload = (files) => {
        if (uploadUrl) {
            let xhr = new XMLHttpRequest();
            xhr.open('POST', uploadUrl, true);
            xhr.upload.onprogress = function (e) {
                if (e.lengthComputable) {
                    setUploadProgress((e.loaded / e.total) * 100);
                }
            };
            xhr.onload = function () {
                if (this.status == 200) {
                    console.log('Upload complete');
                    loadImg();
                }
            };
            let formData = new FormData();
            formData.append('file', files[0]);
            xhr.send(formData);
        }
    };
    const uploading = useMemo(() => {
        return uploadProgress > 0 && uploadProgress < 100;
    }, [uploadProgress]);
    return jsxs("div", { className: "bg-gray-100 py-4 px-3 flex flex-col w-224", children: [jsx("h3", { className: "border-b pb-2 border-gray-200 text-lg", children: "Add Image" }), jsx(ImageViewer, { onSelect: (images) => { setSelected(images); }, images: images, loading: loading }), jsx(Pagination, { containerClassName: 'mt-5', limit: limit, count: count, offset: offset, onPageChanged: (i) => { setOffset((i - 1) * limit); } }), uploadUrl && jsxs(Fragment, { children: [jsx("button", { className: "cursor-pointer underline text-blue-400 my-5", disabled: uploading, onClick: () => { var _a; return (_a = document.getElementById("fileInput")) === null || _a === void 0 ? void 0 : _a.click(); }, children: uploading ? `${uploadProgress.toFixed(0)} %` : 'Upload' }), jsx("div", { className: "h-0 w-0 overflow-hidden", children: jsx("input", { type: "file", id: "fileInput", name: "fileInput", onChange: (e) => {
                                var _a, _b, _c;
                                if (((_a = e === null || e === void 0 ? void 0 : e.target) === null || _a === void 0 ? void 0 : _a.files) && ((_b = e === null || e === void 0 ? void 0 : e.target) === null || _b === void 0 ? void 0 : _b.files[0])) {
                                    upload((_c = e === null || e === void 0 ? void 0 : e.target) === null || _c === void 0 ? void 0 : _c.files);
                                }
                            } }) })] }), jsxs("div", { className: "flex flex-row justify-end gap-2 items-center my-2", children: [jsx("div", { className: "text-gray-400 cursor-pointer", onClick: () => {
                            onCancel();
                        }, children: "Cancel" }), jsx(Button, { onClick: () => {
                            onSelect(selected);
                        }, children: "Confirm" })] })] });
}

export { ImageSelection };
