import { createCommand, ElementNode, $createParagraphNode } from 'lexical';

function convertImageElement(element) {
    const nodeName = element.nodeName.toLowerCase();
    let node = null;
    if (nodeName === 'img') {
        node = $createImageNode(element.src);
    }
    return { node };
}
class ImageNode extends ElementNode {
    static getType() {
        return 'image';
    }
    static clone(node) {
        return new ImageNode(node.__url, node.__key);
    }
    constructor(url, key) {
        super(key);
        this.__url = url;
    }
    createDOM(config) {
        const image = document.createElement('img');
        image.src = this.__url;
        image.classList.add('editor-img');
        return image;
    }
    updateDOM() {
        return false;
    }
    setURL(url) {
        const writable = this.getWritable();
        writable.__url = url;
    }
    static importDOM() {
        return {
            img: (node) => ({
                conversion: convertImageElement,
                priority: 0,
            }),
        };
    }
    exportDOM(editor) {
        const { element } = super.exportDOM(editor);
        if (element && this.isEmpty()) {
            element.append(document.createElement('br'));
        }
        if (element) {
            const formatType = this.getFormatType();
            element.style.textAlign = formatType;
            const direction = this.getDirection();
            if (direction) {
                element.dir = direction;
            }
        }
        return {
            element,
        };
    }
    insertNewAfter(selection, restoreSelection = true) {
        const newElement = $createParagraphNode();
        const direction = this.getDirection();
        newElement.setDirection(direction);
        this.insertAfter(newElement, restoreSelection);
        return newElement;
    }
    collapseAtStart() {
        const newElement = $createParagraphNode();
        const children = this.getChildren();
        children.forEach((child) => newElement.append(child));
        this.replace(newElement);
        return true;
    }
    extractWithChild() {
        return true;
    }
    exportJSON() {
        throw new Error("Method not implemented.");
    }
    static importJSON(_serializedNode) {
        throw new Error("Method not implemented.");
    }
}
function $createImageNode(url) {
    return new ImageNode(url);
}
const INSERT_IMAGE_COMMAND = createCommand('INSERT_IMAGE_COMMAND');

export { $createImageNode, INSERT_IMAGE_COMMAND, ImageNode };
